@@ -7,7 +7,9 @@ for pkg in {"servo", "servox"}:
     except importlib.metadata.PackageNotFoundError:
         pass
 
+import servo.assembly
 import servo.connector
+import servo.errors
 import servo.events
 import servo.types
 import servo.cli
@@ -21,20 +23,21 @@ from .events import (
     EventHandler,
     EventResult, 
     Preposition,
-    EventError,
-    CancelEventError,
-)
-from .connector import (
-    Optimizer,
-    BaseConfiguration,
-    Connector,
-    metadata,
+    create_event,
     event,
     before_event,
     on_event,
     after_event,
     event_handler,
 )
+from .connector import (
+    Optimizer,
+    BaseConfiguration,
+    Connector,
+    metadata,
+)
 
-# Pull the types up to the top level
+# Pull the errors, types & utilities up to the top level
+from .errors import *
 from .types import *
+from .utilities import *
