@@ -6,7 +6,7 @@
 # reinstalls of all package dependencies.
 # Do not implement meaningful functionality here. Instead import and
 # dispatch the intent into focused modules to do the real work.
-from dotenv import load_dotenv, find_dotenv
+from dotenv import find_dotenv, load_dotenv
 from loguru import logger
 
 from servo.cli import ServoCLI
@@ -18,8 +18,11 @@ def run_cli():
 
     # NOTE: We load connectors here because waiting until assembly
     # is too late for registering CLI commands
-    for connector in ConnectorLoader().load():
-        logger.debug(f"Loaded {connector.__qualname__}")
+    try:
+        for connector in ConnectorLoader().load():
+            logger.debug(f"Loaded {connector.__qualname__}")
+    except Exception as error:
+        logger.exception("failed loading connectors via discovery", backtrace=True, diagnose=True)
 
     cli = ServoCLI()
     cli()
